@@ -3,7 +3,7 @@ package HTML::ExtractText;
 use strict;
 use warnings;
 
-our $VERSION = '1.001003'; # VERSION
+our $VERSION = '1.001004'; # VERSION
 
 use Try::Tiny;
 use Scalar::Util qw/blessed/;
@@ -68,6 +68,9 @@ sub extract {
             my @results
             = $dom->find( $what->{ $selector } )->map('all_text')->each;
 
+            # get rid of pesky non-breaking spaces
+            tr/\x{00A0}/ / for @results;
+
             die "NOT FOUND\n"
                 if not @results and not $self->ignore_not_found;
 
@@ -421,6 +424,27 @@ Accessor to C<ignore_not_found> option (see C<< ->new() >>).
 Takes one optional argument, which if provided, will become the
 new value of C<ignore_not_found> option.
 
+=head1 NOTES AND CAVEATS
+
+=head2 Non-breaking spaces
+
+This module automatically converts non-breaking spaces to regular
+spaces, because C<&nbsp;>s have cooties and no one wants to play
+with them.
+
+=head2 Encoding
+
+This module does not automatically encode extracted text, so the
+examples in this documentation should really include something akin to:
+
+    use Encode;
+
+    my $title = encode 'utf8', $ext->{page_title};
+    print "$title\n";
+
+Or a similar approach to encoding, depending on what encoding you're
+actually using.
+
 =head1 SEE ALSO
 
 L<Mojo::DOM>, L<Text::Balanced>, L<HTML::Extract>
